## 3.15.0.2 (2022-11-09)

Annotate known magic-method return types (#9131)

## 3.15.0.1 (2022-11-08)

Fix and allow classes with missing metaclasses (#9136)

## 3.15.0.0 (2022-10-04)

Add auto-generated peewee stubs (#8834)

